@@ -1,12 +1,12 @@
 /***************************************************************************
- *   Copyright (C) 2003 by Hideki Ikemoto                                  *
- *   ikemo@users.sourceforge.jp                                            *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+*   Copyright (C) 2003 by Hideki Ikemoto                                  *
+*   ikemo@users.sourceforge.jp                                            *
+*                                                                         *
+*   This program is free software; you can redistribute it and/or modify  *
+*   it under the terms of the GNU General Public License as published by  *
+*   the Free Software Foundation; either version 2 of the License, or     *
+*   (at your option) any later version.                                   *
+***************************************************************************/
 
 #ifndef _KITA_H_
 #define _KITA_H_
@@ -30,8 +30,9 @@ class KitaBoardView;
 class KitaSubjectTabWidget;
 class KLineEdit;
 
-namespace KParts{
-  class URLArgs;
+namespace KParts
+{
+    class URLArgs;
 };
 
 /**
@@ -60,37 +61,33 @@ public:
     /**
      * Use this method to load whatever file/URL you have
      */
-    void load(const KURL& url);
+    void load( const KURL& url );
 
 protected:
     /**
      * Overridden virtuals for Qt drag 'n drop (XDND)
      */
-    virtual void dragEnterEvent(QDragEnterEvent *event);
-    virtual void dropEvent(QDropEvent *event);
+    virtual void dragEnterEvent( QDragEnterEvent* event );
+    virtual void dropEvent( QDropEvent* event );
 
     /**
      * This function is called when it is time for the app to save its
      * properties for session management purposes.
      */
-    void saveProperties(KConfig *);
+    void saveProperties( KConfig* );
 
     /**
      * This function is called when this app is restored.  The KConfig
      * object points to the session management config file that was saved
      * with @ref saveProperties
      */
-    void readProperties(KConfig *);
+    void readProperties( KConfig* );
 
-    void readConfig(KConfig *);
-    void writeConfig(KConfig *);
+    void readConfig( KConfig* );
+    void writeConfig( KConfig* );
 
 private slots:
     void fileNew();
-    void fileOpen();
-    void fileSave();
-    void fileSaveAs();
-    void filePrint();
     void optionsShowToolbar();
     void optionsShowStatusbar();
     void optionsConfigureKeys();
@@ -100,19 +97,23 @@ private slots:
     void windowShowBoardlist();
     void windowShowSubjectlist();
     void windowMenuAboutToShow();
+    void windowCloseTab();
+    void settingsMenuAboutToShow();
     void slotEditCopy();
+    void slotEditFind();
+    void slotViewReload();
 
-    void changeStatusbar(const QString& text);
-    void changeCaption(const QString& text);
-    void slotOpenURLRequest(const KURL& url, const KParts::URLArgs&);
-    void updateThreadCache( const Kita::Thread& thread );
+    void changeStatusbar( const QString& text );
+    void changeCaption( const QString& text );
+    void slotOpenURLRequest( const KURL& url, const KParts::URLArgs& );
+    void updateThreadCache( const Kita::Thread* thread );
     void setFont( const QFont& font );
     void setThreadFont( const QFont& font );
     void slotWriteSucceeded();
     void slotUrlLine();
-    void setUrl(const KURL& url);
-    void bookmark( const Kita::Thread& thread, bool on );
-    void slotThread( const Kita::Thread& thread );
+    void setUrl( const KURL& url );
+    void bookmark( const Kita::Thread* thread, bool on );
+    void slotThread( const Kita::Thread* thread );
 
 private:
     KitaThreadTabWidget* m_threadView;
@@ -120,7 +121,7 @@ private:
     KitaSubjectTabWidget* m_subjectView;
     KLineEdit* m_urlLine;
 
-    KPrinter   *m_printer;
+    KPrinter *m_printer;
     KToggleAction *m_toolbarAction;
     KToggleAction *m_statusbarAction;
     KToggleAction *m_boardListAction;
@@ -136,6 +137,8 @@ private:
     void saveCache();
     void loadFavorites();
     void saveFavorites();
+    void loadCompletion();
+    void saveCompletion();
 };
 
 #endif // _KITA_H_
