@@ -179,7 +179,7 @@ void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint&
 
   KPopupMenu popup( 0 );
   popup.insertItem( i18n("Open with Web Browser"), 0 );
-  popup.insertItem( i18n("Open with new tab(broken)"), 1 );
+  popup.insertItem( i18n("Open with New Tab"), 1 );
 
   KURL url = item->text(1);
 
@@ -188,7 +188,7 @@ void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint&
     KRun::runURL( url, "text/html" );
     break;
   case 1:
-//    emit signalShowThreadWithNewTab( thread );
+    emit openBoardRequested( Kita::Board::getByURL( url.url() ), true );
     break;
   default:
     break;
