@@ -21,6 +21,8 @@ KitaConfig* KitaConfig::getInstance()
 }
 
 KitaConfig::KitaConfig()
+  : m_threadColor( "black" ), m_threadBackgroundColor( "white" ),
+    m_popupColor( "black" ), m_popupBackgroundColor( "yellow" )
 {
 }
 
